@@ -29,7 +29,9 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
 
 def clean(args, logger=None, no_matchs=False):
     filter = args.filter
-    ignore_dirs = args.ignore_dirs or []
+    ignore_dirs = []
+    if args.ignore_dirs:
+        ignore_dirs = args.ignore_dirs.split(',')
     path = args.path
     for f in all_file(path, filter, ignore_dirs, logger=logger, \
             no_matchs=no_matchs):
